[][src]Module gridly::direction

A simple enumeration for the 4 cardinal directions.

Re-exports

pub use Direction::Down;
pub use Direction::Left;
pub use Direction::Right;
pub use Direction::Up;

Enums

Direction

The four cardinal directions (up, down, left, right). Direction implements a number of simple helper methods. It also implements VectorLike, which allows it to be used in contexts where a Vector can be used as a unit vector in the given direction.