[−][src]Enum gridly::direction::Direction
The four cardinal directions (up, down, left, right). Direction
implements a number of simple helper methods. It also implements
VectorLike, which allows it to be used in contexts where a Vector
can be used as a unit vector in the given direction.
Variants
The negative row direction
The positive row direction
The negative column direction
The positive column direction
Methods
impl Direction[src]
pub fn sized_vec(self, length: isize) -> Vector[src]
Return a vector with the given length in this direction
Example:
use gridly::prelude::*; assert_eq!(Up.sized_vec(2), Vector::new(-2, 0)); assert_eq!(Down.sized_vec(3), Vector::new(3, 0)); assert_eq!(Left.sized_vec(1), Vector::new(0, -1)); assert_eq!(Right.sized_vec(5), Vector::new(0, 5));
pub fn unit_vec(self) -> Vector[src]
Return the unit vector in the given direction.
Example:
use gridly::prelude::*; assert_eq!(Up.unit_vec(), Vector::new(-1, 0)); assert_eq!(Down.unit_vec(), Vector::new(1, 0)); assert_eq!(Left.unit_vec(), Vector::new(0, -1)); assert_eq!(Right.unit_vec(), Vector::new(0, 1));
pub fn is_vertical(self) -> bool[src]
True if this is Up or Down
Example:
use gridly::direction::*; assert!(Up.is_vertical()); assert!(Down.is_vertical()); assert!(!Left.is_vertical()); assert!(!Right.is_vertical());
pub fn is_horizontal(self) -> bool[src]
True if this is Left or Right
Example:
use gridly::direction::*; assert!(!Up.is_horizontal()); assert!(!Down.is_horizontal()); assert!(Left.is_horizontal()); assert!(Right.is_horizontal());
pub fn reverse(self) -> Direction[src]
Reverse this direction (Up -> Down, etc)
use gridly::direction::*; assert_eq!(Up.reverse(), Down); assert_eq!(Down.reverse(), Up); assert_eq!(Left.reverse(), Right); assert_eq!(Right.reverse(), Left);
pub fn clockwise(self) -> Direction[src]
Rotate this direction clockwise
Example:
use gridly::direction::*; assert_eq!(Up.clockwise(), Right); assert_eq!(Down.clockwise(), Left); assert_eq!(Left.clockwise(), Up); assert_eq!(Right.clockwise(), Down);
pub fn anticlockwise(self) -> Direction[src]
Rotate this direction counterclockwise
Example:
use gridly::direction::*; assert_eq!(Up.anticlockwise(), Left); assert_eq!(Down.anticlockwise(), Right); assert_eq!(Left.anticlockwise(), Down); assert_eq!(Right.anticlockwise(), Up);