BoundsError

Enum BoundsError 

pub enum BoundsError {
    Row(RowRangeError),
    Column(ColumnRangeError),
    Both {
        row: RowRangeError,
        column: ColumnRangeError,
    },
}
An out-of-bounds error for a Location on a grid

This error is returned by methods that perform bounds checking to indicate a failed bounds check. It includes the specific boundary or boundaries that were violated.

Variants



Row(RowRangeError)

The location’s Row was out of bounds.



Column(ColumnRangeError)

The location’s Column was out of bounds.



Both

Both the Row and the Column were out of bounds.

Implementations

Source

impl BoundsError

pub fn row(&self) -> Option<&RowRangeError>

The row component of the boundary error, if applicable.

use gridly::prelude::*;

let row_error = RowRangeError::TooLow(Row(0));
let col_error = ColumnRangeError::TooLow(Column(0));

assert_eq!(BoundsError::Row(row_error).row(), Some(&row_error));
assert_eq!(BoundsError::Column(col_error).row(), None);
assert_eq!(
    BoundsError::Both{row: row_error, column: col_error}.row(), Some(&row_error)
);
pub fn column(&self) -> Option<&ColumnRangeError>

The column component of the boundary error, if applicable.

use gridly::prelude::*;

let row_error = RowRangeError::TooLow(Row(0));
let col_error = ColumnRangeError::TooLow(Column(0));

assert_eq!(BoundsError::Row(row_error).column(), None);
assert_eq!(BoundsError::Column(col_error).column(), Some(&col_error));
assert_eq!(
    BoundsError::Both{row: row_error, column: col_error}.column(), Some(&col_error)
);