[−][src]Struct gridly::vector::Vector
A measurement of distance between two [Location]s
A vector is the measurement of distance between two [Location]s. It
supports arithmetic operations with itself, as well as anything which can
be converted into a Vector. Currently, Rows, Columns, and Direction
all have this property, as well as a tuple of (Into
Fields
rows: Rowscolumns: ColumnsMethods
impl Vector[src]
pub fn new(rows: impl Into<Rows>, columns: impl Into<Columns>) -> Self[src]
Create a new Vector
pub fn zero() -> Vector[src]
Create a zero Vector
pub fn upward(size: isize) -> Vector[src]
Create an upward pointing vector of the given size
pub fn downward(size: isize) -> Vector[src]
Create a downward pointing vector of the given size
pub fn leftward(size: isize) -> Vector[src]
Create a leftward pointing vector of the given size
pub fn rightward(size: isize) -> Vector[src]
Create a rightward pointing vector of the given size
pub fn in_direction(direction: Direction, length: isize) -> Vector[src]
Create a vector of the given size in the given direction
pub fn manhattan_length(&self) -> isize[src]
Return the Manhattan length of the vector
The Manhattan length of a vector is the sum of the absolute values of its components
pub fn clockwise(&self) -> Vector[src]
Return a new vector, rotated 90 degrees clockwise.
pub fn counterclockwise(&self) -> Vector[src]
Return a new vector, rotated 90 degrees counterclockwise.
pub fn reverse(&self) -> Vector[src]
pub fn get_component<T: Component>(&self) -> T[src]
Generically get either the Rows or Columns of a vector
pub fn transpose(&self) -> Vector[src]
Swap the rows and columns of this Vector