RangeError

Enum RangeError 

pub enum RangeError<T: Component> {
    TooLow(T),
    TooHigh(T),
}
Error indicating that a Row or Column was out of bounds.

Note that the bounds expressed in this error are half inclusive; that is, the lower bound in TooLow is an inclusive lower bound, but the upper bound in TooHigh is an exclusive upper bound. This is consistent with the conventional range representation of low..high.

Example:

use gridly::range::{ComponentRange, RangeError};
use gridly::location::Row;
let range = ComponentRange::bounded(Row(0), Row(10));


assert_eq!(range.check(-5), Err(RangeError::TooLow(Row(0))));
assert_eq!(range.check(15), Err(RangeError::TooHigh(Row(10))));
assert_eq!(range.check(10), Err(RangeError::TooHigh(Row(10))));

Variants



TooLow(T)

The given row or column was too low. The value in the error is the minimum row or column, inclusive.



TooHigh(T)

The given row or column was too high. The given value in the error is the maximum row or column, exclusive (that is, a value equal to the error value is considered too high).